import orderActive from '@/static/images/home-active.png'
import order from '@/static/images/home.png'
import taskActive from '@/static/images/assignment-active.png'
import task from '@/static/images/assignment.png'
import clientInActive from '@/static/images/client-inactive.png'
import clientActive from '@/static/images/client-active.png'
import contractActive from '@/static/images/contract-active.png'
import contractInActive from '@/static/images/contract-inactive.png'
import profileInActive from '@/static/images/profile-inactive.png'
import profileActive from '@/static/images/profile-active.png'
import { type TabBarProp } from '@/stores/tabbar'
import { useUserStore } from '@/stores/user'
import cache from '@/utils/cache'
import { ROLEINDEX } from '@/enums/cacheEnums'
import { computed } from 'vue'
import { ApprenticeEnum } from '@/enums/businessEnums'
export interface RoleItem {
    name: string
    ids: number[]
    tabBarList: TabBarProp[]
}

export function useRoleData() {
    const roles: RoleItem[] = [
        {
            name: '业务员',
            ids: [8, 9],
            tabBarList: [
                {
                    text: '客户库',
                    inactiveIcon: clientInActive,
                    activeIcon: clientActive,
                    path: '/pages/salesman/client/index'
                },
                {
                    text: '合同管理',
                    path: '/pages/salesman/contract/index',
                    inactiveIcon: contractInActive,
                    activeIcon: contractActive
                },
                {
                    text: '个人中心',
                    path: '/pages/salesman/profile/index',
                    inactiveIcon: profileInActive,
                    activeIcon: profileActive
                }
            ]
        },
        {
            name: '检修员',
            ids: [6],
            tabBarList: [
                {
                    text: '工单池',
                    inactiveIcon: order,
                    activeIcon: orderActive,
                    path: '/pages/overhaul/pool/index'
                },
                {
                    text: '我的任务',
                    inactiveIcon: task,
                    activeIcon: taskActive,
                    path: '/pages/overhaul/task/index'
                },
                {
                    text: '个人中心',
                    inactiveIcon: profileInActive,
                    activeIcon: profileActive,
                    path: '/pages/overhaul/my/index'
                }
            ]
        },
        {
            name: '客户',
            ids: [1, 2, 11],
            tabBarList: [
                {
                    text: '工单记录',
                    inactiveIcon: order,
                    activeIcon: orderActive,
                    path: '/pages/client/workOrder/index'
                },
                {
                    text: '个人中心',
                    inactiveIcon: profileInActive,
                    activeIcon: profileActive,
                    path: '/pages/client/my/index'
                }
            ]
        },
        {
            name: '维修员',
            ids: [7],
            tabBarList: [
                // {
                //     text: '工单池',
                //     inactiveIcon: order,
                //     activeIcon: orderActive,
                //     path: '/pages/repair/pool/index'
                // },
                {
                    text: '工单列表',
                    inactiveIcon: task,
                    activeIcon: taskActive,
                    path: '/pages/repair/task/index'
                },
                {
                    text: '个人中心',
                    inactiveIcon: profileInActive,
                    activeIcon: profileActive,
                    path: '/pages/repair/my/index'
                }
            ]
        },
        {
            name: '维修主管',
            ids: [10],
            tabBarList: [
                {
                    text: '工单列表',
                    inactiveIcon: task,
                    activeIcon: taskActive,
                    path: '/pages/charge/order/index'
                },
                {
                    text: '个人中心',
                    inactiveIcon: profileInActive,
                    activeIcon: profileActive,
                    path: '/pages/charge/my/index'
                }
            ]
        }
    ]
    return {
        roles
    }
}

export function useRoleActiveId() {
    const userStore = useUserStore()
    const { userInfo } = userStore
    const roleIndex = cache.get(ROLEINDEX)
    const activeRoleId = computed(() => {
        const roleArr = userInfo.roles
        return roleArr[roleIndex || 0]?.id
    })
    return {
        activeRoleId
    }
}

export function useJudgeApprentice() {
    const userStore = useUserStore()
    const { userInfo } = userStore
    if (typeof userInfo.isApprentice == undefined) return false
    return userInfo?.isApprentice === ApprenticeEnum.NO ? false : true
}
